@@ -18,8 +18,6 @@
 """CubicWeb is a generic framework to quickly build applications which describes
 relations between entitites.
 """
-from __future__ import with_statement
-
 __docformat__ = "restructuredtext en"
 
 # ignore the pygments UserWarnings
@@ -217,7 +215,7 @@ def validation_error(entity, errors, substitutions=None, i18nvalues=None):
         # set empty dict else translation won't be done for backward
         # compatibility reason (see ValidationError.translate method)
         substitutions = {}
-    for key in errors.keys():
+    for key in list(errors):
         if isinstance(key, tuple):
             errors[rname(*key)] = errors.pop(key)
     return ValidationError(getattr(entity, 'eid', entity), errors,
