@@ -91,7 +91,7 @@ Examples:
    # web/views/basecomponents.py
    def registration_callback(vreg):
       # register everything in the module except SeeAlsoComponent
-      vreg.register_all(globals().values(), __name__, (SeeAlsoVComponent,))
+      vreg.register_all(globals().itervalues(), __name__, (SeeAlsoVComponent,))
       # conditionally register SeeAlsoVComponent
       if 'see_also' in vreg.schema:
           vreg.register(SeeAlsoVComponent)
@@ -197,7 +197,7 @@ import sys
 from os.path import join, dirname, realpath
 from warnings import warn
 from datetime import datetime, date, time, timedelta
-from functools import partial
+from functools import partial, reduce
 
 from logilab.common.decorators import cached, clear_cache
 from logilab.common.deprecation import deprecated, class_deprecated
@@ -210,16 +210,25 @@ from rql import RQLHelper
 from yams.constraints import BASE_CONVERTERS
 
 from cubicweb import (CW_SOFTWARE_ROOT, ETYPE_NAME_MAP, CW_EVENT_MANAGER,
-                      Binary, UnknownProperty, UnknownEid)
+                      onevent, Binary, UnknownProperty, UnknownEid)
 from cubicweb.predicates import (implements, appobject_selectable,
                                  _reset_is_instance_cache)
 
-# backward compat: those modules are now refering to app objects in
-# cw.web.views.uicfg and import * from backward compat. On registry reload, we
-# should pop those modules from the cache so references are properly updated on
-# subsequent reload
-CW_EVENT_MANAGER.bind('before-registry-reload', partial(sys.modules.pop, 'cubicweb.web.uicfg', None))
-CW_EVENT_MANAGER.bind('before-registry-reload', partial(sys.modules.pop, 'cubicweb.web.uihelper', None))
+
+@onevent('before-registry-reload')
+def cleanup_uicfg_compat():
+    """ backward compat: those modules are now refering to app objects in
+    cw.web.views.uicfg and import * from backward compat. On registry reload, we
+    should pop those modules from the cache so references are properly updated on
+    subsequent reload
+    """
+    if 'cubicweb.web' in sys.modules:
+        if getattr(sys.modules['cubicweb.web'], 'uicfg', None):
+            del sys.modules['cubicweb.web'].uicfg
+        if getattr(sys.modules['cubicweb.web'], 'uihelper', None):
+            del sys.modules['cubicweb.web'].uihelper
+    sys.modules.pop('cubicweb.web.uicfg', None)
+    sys.modules.pop('cubicweb.web.uihelper', None)
 
 def use_interfaces(obj):
     """return interfaces required by the given object by searching for
@@ -624,7 +633,7 @@ class CWRegistryStore(RegistryStore):
         """
         self.schema = schema
         for registry, regcontent in self.items():
-            for objects in regcontent.values():
+            for objects in regcontent.itervalues():
                 for obj in objects:
                     obj.schema = schema
 
@@ -725,7 +734,7 @@ class CWRegistryStore(RegistryStore):
                     self.unregister(obj)
         super(CWRegistryStore, self).initialization_completed()
         if 'uicfg' in self: # 'uicfg' is not loaded in a pure repository mode
-            for rtags in self['uicfg'].values():
+            for rtags in self['uicfg'].itervalues():
                 for rtag in rtags:
                     # don't check rtags if we don't want to cleanup_interface_sobjects
                     rtag.init(self.schema, check=self.config.cleanup_interface_sobjects)
@@ -816,10 +825,10 @@ class CWRegistryStore(RegistryStore):
         for key, val in propvalues:
             try:
                 values[key] = self.typed_value(key, val)
-            except ValueError, ex:
+            except ValueError as ex:
                 self.warning('%s (you should probably delete that property '
                              'from the database)', ex)
-            except UnknownProperty, ex:
+            except UnknownProperty as ex:
                 self.warning('%s (you should probably delete that property '
                              'from the database)', ex)
 
