@@ -35,7 +35,7 @@ try:
     import windmill
     from windmill.dep import functest
     from windmill.bin.admin_lib import configure_global_settings, setup, teardown
-except ImportError, ex:
+except ImportError:
     windmill = None
 
 from cubicweb.devtools.httptest import CubicWebServerTC, CubicWebServerConfig
@@ -45,7 +45,7 @@ if windmill is None:
         tags = CubicWebServerTC.tags & Tags(('windmill',))
 
         def testWindmill(self):
-            self.skipTest("can't import windmill %s" % ex)
+            self.skipTest("can't import windmill")
 else:
     # Excerpt from :ref:`windmill.authoring.unit`
     class UnitTestReporter(functest.reports.FunctestReportInterface):
