@@ -20,9 +20,6 @@
 * integrity of a CubicWeb repository. Hum actually only the system database is
   checked.
 """
-
-from __future__ import with_statement
-
 __docformat__ = "restructuredtext en"
 
 import sys
@@ -288,7 +285,7 @@ def check_relations(schema, session, eids, fix=1):
             continue
         try:
             cursor = session.system_sql('SELECT eid_from FROM %s_relation;' % rschema)
-        except Exception, ex:
+        except Exception as ex:
             # usually because table doesn't exist
             print 'ERROR', ex
             continue
@@ -320,7 +317,7 @@ def check_mandatory_relations(schema, session, eids, fix=1):
             continue
         smandatory = set()
         omandatory = set()
-        for rdef in rschema.rdefs.values():
+        for rdef in rschema.rdefs.itervalues():
             if rdef.cardinality[0] in '1+':
                 smandatory.add(rdef.subject)
             if rdef.cardinality[1] in '1+':
@@ -348,7 +345,7 @@ def check_mandatory_attributes(schema, session, eids, fix=1):
     for rschema in schema.relations():
         if not rschema.final or rschema in VIRTUAL_RTYPES:
             continue
-        for rdef in rschema.rdefs.values():
+        for rdef in rschema.rdefs.itervalues():
             if rdef.cardinality[0] in '1+':
                 rql = 'Any X WHERE X %s NULL, X is %s, X cw_source S, S name "system"' % (
                     rschema, rdef.subject)
