@@ -16,9 +16,6 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
 """helper classes to handle server-side edition of entities"""
-
-from __future__ import with_statement
-
 __docformat__ = "restructuredtext en"
 
 from copy import copy
@@ -144,7 +141,7 @@ class EditedEntity(dict):
         try:
             entity.e_schema.check(dict_protocol_catcher(entity),
                                   creation=creation, relations=relations)
-        except ValidationError, ex:
+        except ValidationError as ex:
             ex.entity = self.entity
             raise
 
