@@ -18,8 +18,6 @@
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
 """unit tests for cubicweb.web.views.entities module"""
 
-from __future__ import with_statement
-
 from datetime import datetime
 
 from logilab.common import tempattr
@@ -129,11 +127,11 @@ class EntityTC(CubicWebTC):
         self.assertEqual(user._cw_related_cache, {})
         email = user.primary_email[0]
         self.assertEqual(sorted(user._cw_related_cache), ['primary_email_subject'])
-        self.assertEqual(email._cw_related_cache.keys(), ['primary_email_object'])
+        self.assertEqual(list(email._cw_related_cache), ['primary_email_object'])
         groups = user.in_group
         self.assertEqual(sorted(user._cw_related_cache), ['in_group_subject', 'primary_email_subject'])
         for group in groups:
-            self.assertFalse('in_group_subject' in group._cw_related_cache, group._cw_related_cache.keys())
+            self.assertFalse('in_group_subject' in group._cw_related_cache, list(group._cw_related_cache))
 
     def test_related_limit(self):
         req = self.request()
@@ -143,6 +141,9 @@ class EntityTC(CubicWebTC):
         self.execute('SET X tags Y WHERE X is Tag, Y is Personne')
         self.assertEqual(len(p.related('tags', 'object', limit=2)), 2)
         self.assertEqual(len(p.related('tags', 'object')), 4)
+        p.cw_clear_all_caches()
+        self.assertEqual(len(p.related('tags', 'object', entities=True, limit=2)), 2)
+        self.assertEqual(len(p.related('tags', 'object', entities=True)), 4)
 
     def test_cw_instantiate_relation(self):
         req = self.request()
