@@ -24,9 +24,8 @@ from logilab.mtconverter import xml_escape
 
 from cubicweb import Unauthorized, typed_eid
 from cubicweb.predicates import is_instance, one_line_rset
-from cubicweb.web import (action, component, uicfg, htmlwidgets,
-                          formwidgets as fw)
-from cubicweb.web.views import primary
+from cubicweb.web import action, component, htmlwidgets, formwidgets as fw
+from cubicweb.web.views import uicfg, primary
 from cubicweb.web.views.ajaxcontroller import ajaxfunc
 
 _abaa = uicfg.actionbox_appearsin_addmenu
